about summary refs log tree commit diff
diff options
context:
space:
mode:
authorgiraffedata <giraffedata@9d0c8265-081b-0410-96cb-a4ca84ce46f8>2021-05-21 04:25:05 +0000
committergiraffedata <giraffedata@9d0c8265-081b-0410-96cb-a4ca84ce46f8>2021-05-21 04:25:05 +0000
commit096ed0ec22835021832055ffc3a364e4f7632a28 (patch)
treea349f0981f9e9373cc0f840ef322a8b7af302424
parent64145413fe65664164974fb1cc7f387a1d984c63 (diff)
downloadnetpbm-mirror-096ed0ec22835021832055ffc3a364e4f7632a28.tar.gz
netpbm-mirror-096ed0ec22835021832055ffc3a364e4f7632a28.tar.xz
netpbm-mirror-096ed0ec22835021832055ffc3a364e4f7632a28.zip
Change -transparency to -transparent, per documentation (and design)
git-svn-id: http://svn.code.sf.net/p/netpbm/code/trunk@4111 9d0c8265-081b-0410-96cb-a4ca84ce46f8
-rw-r--r--converter/other/pamtopng.c14
-rw-r--r--doc/HISTORY6
2 files changed, 12 insertions, 8 deletions
diff --git a/doc/HISTORY b/doc/HISTORY
index 1dd29909..86d35f7c 100644
--- a/doc/HISTORY
+++ b/doc/HISTORY
@@ -18,7 +18,11 @@ not yet  BJH  Release 10.95.00
               pamtopng: Fix: treats all tuple types that start with BLA as
               BLACKANDWHITE.  Always broken (pamtopng was new in Netpbm 10.71
               (June 2015)).
-              
+
+              pamtopng: Fix -transparent option - program recognized
+              -transparency instead.  Always broken (pamtopng was new in
+              Netpbm 10.71 (June 2015)).
+
               pamtogif: Fix failure with bogus message about wrong depth with
               grayscale and black and white PAM images with transparency.
               Always broken (pamtogif was new in Netpbm 10.37 (December 2006)).
diff --git a/converter/other/pamtopng.c b/converter/other/pamtopng.c
index 327a2b1f..b61ab17b 100644
--- a/converter/other/pamtopng.c
+++ b/converter/other/pamtopng.c
@@ -50,8 +50,8 @@ struct CmdlineInfo {
     const char * inputFileName;
     unsigned int verbose;
     unsigned int interlace;
-    unsigned int transparencySpec;
-    const char * transparency;
+    unsigned int transparentSpec;
+    const char * transparent;
     unsigned int chromaSpec;
     struct pngx_chroma chroma;
     unsigned int gammaSpec;
@@ -196,8 +196,8 @@ parseCommandLine (int                  argc,
             &cmdlineP->verbose,        0);
     OPTENT3(0,  "interlace",    OPT_FLAG,       NULL,
             &cmdlineP->interlace,      0);
-    OPTENT3(0,  "transparency", OPT_STRING,     &cmdlineP->transparency,
-            &cmdlineP->transparencySpec, 0);
+    OPTENT3(0,  "transparent", OPT_STRING,      &cmdlineP->transparent,
+            &cmdlineP->transparentSpec, 0);
     OPTENT3(0,  "chroma",       OPT_STRING,     &chroma,
             &cmdlineP->chromaSpec,     0);
     OPTENT3(0,  "gamma",        OPT_FLOAT,      &cmdlineP->gamma,
@@ -413,7 +413,7 @@ doTrnsChunk(const struct pam * const pamP,
     else {
         xelval const pngMaxval = pm_bitstomaxval(pngx_bitDepth(pngxP));
         png_color_16 const pngColor = parseAndScaleColor(trans, pngMaxval);
             /* Transparency color from text format scaled from 16-bit to
                maxval.
             */
 
@@ -816,8 +816,8 @@ addAncillaryChunks(struct pam *       const pamP,
 /*----------------------------------------------------------------------------
   Where requested, add ancillary chunks.
 -----------------------------------------------------------------------------*/
-    if (cmdline.transparencySpec)
-        doTrnsChunk(pamP, pngxP,cmdline.transparency);
+    if (cmdline.transparentSpec)
+        doTrnsChunk(pamP, pngxP,cmdline.transparent);
 
     if (cmdline.chromaSpec)
         doChrmChunk(pngxP, cmdline.chroma);
@@ -413,7 +413,7 @@ doTrnsChunk(const struct pam * const pamP,
         xelval const pngMaxval = pm_bitstomaxval(pngx_bitDepth(pngxP));
         png_color_16 const pngColor = parseAndScaleColor(trans, pngMaxval);
-            /* Transparency color from text format scaled from 16-bit to
+            /* Transparent color from text format scaled from 16-bit to
                maxval.
             */